pub struct GroupMemberFlags(/* private fields */);Expand description
Represents a bitfield.
Implementations
Sourceimpl GroupMemberFlags
impl GroupMemberFlags
Sourcepub const IS_SELF_BITS: u32 = 1u32
pub const IS_SELF_BITS: u32 = 1u32
The number of bits is_self occupies in the bitfield.
Sourcepub const IS_SELF_OFFSET: u32 = 0u32
pub const IS_SELF_OFFSET: u32 = 0u32
The bit offset of is_self in the bitfield.
Sourcepub const IS_IN_INSTANCE_BITS: u32 = 1u32
pub const IS_IN_INSTANCE_BITS: u32 = 1u32
The number of bits is_in_instance occupies in the bitfield.
Sourcepub const IS_IN_INSTANCE_OFFSET: u32 = 1u32
pub const IS_IN_INSTANCE_OFFSET: u32 = 1u32
The bit offset of is_in_instance in the bitfield.
Sourcepub const IS_COMMANDER_BITS: u32 = 1u32
pub const IS_COMMANDER_BITS: u32 = 1u32
The number of bits is_commander occupies in the bitfield.
Sourcepub const IS_COMMANDER_OFFSET: u32 = 2u32
pub const IS_COMMANDER_OFFSET: u32 = 2u32
The bit offset of is_commander in the bitfield.
Sourcepub const IS_LIEUTENANT_BITS: u32 = 1u32
pub const IS_LIEUTENANT_BITS: u32 = 1u32
The number of bits is_lieutenant occupies in the bitfield.
Sourcepub const IS_LIEUTENANT_OFFSET: u32 = 3u32
pub const IS_LIEUTENANT_OFFSET: u32 = 3u32
The bit offset of is_lieutenant in the bitfield.
Sourcepub const fn new_without_defaults() -> Self
pub const fn new_without_defaults() -> Self
Creates a new bitfield instance without respecting default values.
Sourcepub const fn from_bits_with_defaults(bits: u32) -> Self
pub const fn from_bits_with_defaults(bits: u32) -> Self
Creates a new bitfield instance from the given bits while respecting defaults.
Sourcepub const fn from_le_bits(bits: u32) -> Self
pub const fn from_le_bits(bits: u32) -> Self
Creates a new bitfield instance from the given little-endian bits.
Sourcepub const fn from_le_bits_with_defaults(bits: u32) -> Self
pub const fn from_le_bits_with_defaults(bits: u32) -> Self
Creates a new bitfield instance from the given little-endian bits while respecting defaults.
Sourcepub const fn from_be_bits(bits: u32) -> Self
pub const fn from_be_bits(bits: u32) -> Self
Creates a new bitfield instance from the given big-endian bits.
Sourcepub const fn from_be_bits_with_defaults(bits: u32) -> Self
pub const fn from_be_bits_with_defaults(bits: u32) -> Self
Creates a new bitfield instance from the given big-endian bits while respecting defaults.
Sourcepub const fn into_le_bits(self) -> u32
pub const fn into_le_bits(self) -> u32
Returns the bits of the bitfield in little-endian order.
Sourcepub const fn into_be_bits(self) -> u32
pub const fn into_be_bits(self) -> u32
Returns the bits of the bitfield in big-endian order.
Sourcepub const fn is_in_instance(&self) -> bool
pub const fn is_in_instance(&self) -> bool
Returns bit 1.
Sourcepub const fn is_commander(&self) -> bool
pub const fn is_commander(&self) -> bool
Returns bit 2.
Sourcepub const fn is_lieutenant(&self) -> bool
pub const fn is_lieutenant(&self) -> bool
Returns bit 3.
Sourcepub const fn set_is_self(&mut self, bits: bool)
pub const fn set_is_self(&mut self, bits: bool)
Sets bit 0.
Sourcepub const fn checked_set_is_self(
&mut self,
bits: bool,
) -> Result<(), &'static str>
pub const fn checked_set_is_self( &mut self, bits: bool, ) -> Result<(), &'static str>
Sets bit 0.
Sourcepub const fn set_is_in_instance(&mut self, bits: bool)
pub const fn set_is_in_instance(&mut self, bits: bool)
Sets bit 1.
Sourcepub const fn checked_set_is_in_instance(
&mut self,
bits: bool,
) -> Result<(), &'static str>
pub const fn checked_set_is_in_instance( &mut self, bits: bool, ) -> Result<(), &'static str>
Sets bit 1.
Sourcepub const fn set_is_commander(&mut self, bits: bool)
pub const fn set_is_commander(&mut self, bits: bool)
Sets bit 2.
Sourcepub const fn checked_set_is_commander(
&mut self,
bits: bool,
) -> Result<(), &'static str>
pub const fn checked_set_is_commander( &mut self, bits: bool, ) -> Result<(), &'static str>
Sets bit 2.
Sourcepub const fn set_is_lieutenant(&mut self, bits: bool)
pub const fn set_is_lieutenant(&mut self, bits: bool)
Sets bit 3.
Sourcepub const fn checked_set_is_lieutenant(
&mut self,
bits: bool,
) -> Result<(), &'static str>
pub const fn checked_set_is_lieutenant( &mut self, bits: bool, ) -> Result<(), &'static str>
Sets bit 3.
Sourcepub const fn write_bits(&mut self, bits: u32)
pub const fn write_bits(&mut self, bits: u32)
Writes bits to the bitfield.
Sourcepub const fn write_bits_with_defaults(&mut self, bits: u32)
pub const fn write_bits_with_defaults(&mut self, bits: u32)
Writes bits to the bitfield while setting defaults.
Sourcepub const fn write_le_bits(&mut self, bits: u32)
pub const fn write_le_bits(&mut self, bits: u32)
Writes little-endian bits to the bitfield.
Sourcepub const fn write_le_bits_with_defaults(&mut self, bits: u32)
pub const fn write_le_bits_with_defaults(&mut self, bits: u32)
Writes little-endian bits to the bitfield while setting defaults.
Sourcepub const fn write_be_bits(&mut self, bits: u32)
pub const fn write_be_bits(&mut self, bits: u32)
Writes big-endian bits to the bitfield.
Sourcepub const fn write_be_bits_with_defaults(&mut self, bits: u32)
pub const fn write_be_bits_with_defaults(&mut self, bits: u32)
Writes big-endian bits to the bitfield while setting defaults.
Sourcepub const fn write_defaults(&mut self)
pub const fn write_defaults(&mut self)
Writes the bitfield defaults.
Sourcepub const fn checked_set_bit(
&mut self,
offset: u32,
bit: bool,
) -> Result<(), &'static str>
pub const fn checked_set_bit( &mut self, offset: u32, bit: bool, ) -> Result<(), &'static str>
Sets a bit in the bitfield. Returns an error if the offset is outside the bitfield range.
Sourcepub const fn set_bits_range(&mut self, offset: u32, length: u32, value: u32)
pub const fn set_bits_range(&mut self, offset: u32, length: u32, value: u32)
Sets bits in the bitfield starting from the offset to the length with the provided value.
Sourcepub const fn checked_set_bits_range(
&mut self,
offset: u32,
length: u32,
value: u32,
) -> Result<(), &'static str>
pub const fn checked_set_bits_range( &mut self, offset: u32, length: u32, value: u32, ) -> Result<(), &'static str>
Sets bits in the bitfield starting from the offset to the length with the provided value. Returns an error if the offset and length is outside the bitfield range, if the value is too large for the length, or if any bit in the range is non-writable.
Sourcepub const fn checked_get_bit(&self, offset: u32) -> Result<bool, &'static str>
pub const fn checked_get_bit(&self, offset: u32) -> Result<bool, &'static str>
Returns a bit from the bitfield. Returns an error if the offset is outside the bitfield range.
Sourcepub const fn get_bits_range(&self, offset: u32, length: u32) -> u32
pub const fn get_bits_range(&self, offset: u32, length: u32) -> u32
Returns bits from the bitfield.
Sourcepub const fn checked_get_bits_range(
&self,
offset: u32,
length: u32,
) -> Result<u32, &'static str>
pub const fn checked_get_bits_range( &self, offset: u32, length: u32, ) -> Result<u32, &'static str>
Returns bits from the bitfield starting from the offset to the length. Returns an error if the offset and length is outside the bitfield range or if any bit in the range is non-readable.
Sourcepub const fn clear_bits(&mut self)
pub const fn clear_bits(&mut self)
Clears all bits in the bitfield.
Sourcepub const fn clear_bits_with_defaults(&mut self)
pub const fn clear_bits_with_defaults(&mut self)
Clears all bits in the bitfield and set field defaults.
Sourcepub const fn clear_is_self(&mut self)
pub const fn clear_is_self(&mut self)
Clears bit 0.
Sourcepub const fn clear_is_in_instance(&mut self)
pub const fn clear_is_in_instance(&mut self)
Clears bit 1.
Sourcepub const fn clear_is_commander(&mut self)
pub const fn clear_is_commander(&mut self)
Clears bit 2.
Sourcepub const fn clear_is_lieutenant(&mut self)
pub const fn clear_is_lieutenant(&mut self)
Clears bit 3.
Sourcepub const fn invert_bits(&mut self)
pub const fn invert_bits(&mut self)
Inverts all writable bits in the bitfield.
Sourcepub const fn invert_is_self(&mut self)
pub const fn invert_is_self(&mut self)
Inverts bit 0.
Sourcepub const fn invert_is_in_instance(&mut self)
pub const fn invert_is_in_instance(&mut self)
Inverts bit 1.
Sourcepub const fn invert_is_commander(&mut self)
pub const fn invert_is_commander(&mut self)
Inverts bit 2.
Sourcepub const fn invert_is_lieutenant(&mut self)
pub const fn invert_is_lieutenant(&mut self)
Inverts bit 3.
Sourcepub const fn is_self_inverted(&self) -> bool
pub const fn is_self_inverted(&self) -> bool
Inverts bit 0.
Sourcepub const fn is_in_instance_inverted(&self) -> bool
pub const fn is_in_instance_inverted(&self) -> bool
Inverts bit 1.
Sourcepub const fn is_commander_inverted(&self) -> bool
pub const fn is_commander_inverted(&self) -> bool
Inverts bit 2.
Sourcepub const fn is_lieutenant_inverted(&self) -> bool
pub const fn is_lieutenant_inverted(&self) -> bool
Inverts bit 3.